# icsr_metrics
Metrics for ICSR prediction. In development.

`pip install .`

## TODOS
Implementation:
- init document/icsr from string
- init datasets from strings
- be mindful of normalization schemes in evidence finder,
- Build metric overview
- Add more metrics: e.g. drug extraction, ROUGE

Results:
- Get filtering statistics from evidence finders
- Understand the impact of evidence on evaluation
- 